/*
 * This tests an app flow on the cloudron. User installs
 * an app, tries to configure and then uninstall it.
 */

'use strict';

var AppStore = require('../appstore.js'),
    assert = require('assert'),
    Cloudron = require('../cloudron.js'),
    common = require('../common.js'),
    request = require('superagent-sync');

require('colors');

process.env.NODE_TLS_REJECT_UNAUTHORIZED = '0';
var BOX_VERSION = process.env.BOX_VERSION;

describe('Application flow test', function () {
    this.timeout(0);

    var appStore = new AppStore('https://api.staging.cloudron.io');

    var owner = common.getOwner();
    var admin = common.getAdmin();
    var cloudron, appId, box;

    it('can login to the store', function () {
        var accessToken = appStore.getAccessToken(owner);
        appStore.setCredentials(owner.password, accessToken);

        var adminAccessToken = appStore.getAccessToken(admin);
        appStore.setAdminCredentials(admin.password, adminAccessToken);
    });

    it('can create a cloudron', function () {
        box = appStore.createCloudron({
            domain: common.cloudronDomain(__filename),
            region: 'sfo1',
            size: '1gb',
            version: BOX_VERSION
        });
        box = appStore.waitForCloudron(box.id);
        cloudron = new Cloudron(box);
    });

    it('can activate the box', function () {
        cloudron.activate(owner);
    });

    it('can login to the box', function () {
        var token = cloudron.getOauthToken(owner);
        cloudron.setCredentials(owner.password, token);
    });

    var location = 'test' + (Math.random() * 10000).toFixed();
    it('can install app', function () {
        var manifest = appStore.getManifest(common.TESTAPP_ID, common.TESTAPP_VERSION);
        appId = cloudron.installApp(location, manifest);
    });

    it('can populate the addons', function () {
        var res = request.post('https://' + location + '-' + box.domain + '/populate_addons').end();
        assert.strictEqual(res.statusCode, 200);
        assert.strictEqual(res.body.mysql, 'OK');
        assert.strictEqual(res.body.postgresql, 'OK');
        assert.strictEqual(res.body.mongodb, 'OK');
        assert.strictEqual(res.body.localstorage, 'OK');
        assert.strictEqual(res.body.redis, 'OK');
    });

    it('can check the addons', function () {
        cloudron.checkAddons(location, owner);
    });

    it('displays app graphs', function () {
        cloudron.checkAppGraphs(appId);
    });

    it('can configure app', function () {
        location = location + 'x';
        cloudron.configureApp(appId, location);
    });

    it('can check the addons', function () {
        cloudron.checkAddons(location, owner);
    });

    it('can reboot the cloudron', function () {
        cloudron.reboot();
    });

    it('can check the addons', function () {
        cloudron.checkAddons(location, owner);
    });

    it('can uninstall app', function () {
        cloudron.uninstallApp(appId);
    });

    it('can delete the cloudron', function () {
        appStore.deleteCloudron(box);
    });
});

